@@ -335,13 +335,6 @@ sub parse {
                 $v->{'T'} = sprintf( "%02d:%02d:%02d", $1, $2, $3 );
             }
 
-        } elsif( $p =~ m/\A(\d{1,2}):(\d{1,2}):(\d{1,2})\z/ ) {
-            # Time: 1:2:3
-            if( int($1) < 24 && $2 < 60 && $3 < 60 ) {
-                # Valid time format, maybe...
-                $v->{'T'} = sprintf( "%02d:%02d:%02d", $1, $2, $3 );
-            }
-
         } elsif( $p =~ m/\A([0-2]\d):([0-5]\d)\z/ ) {
             # Time; 12:34 => 12:34:00
             if( $1 < 24 && $2 < 60 ) {
